@@ -10,29 +10,29 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.31.5-127.fc12.src.rpm ]
+if [ ! -r kernel-2.6.31.6-166.fc12.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/development/source/SRPMS/kernel-2.6.31.5-127.fc12.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/12/SRPMS/kernel-2.6.31.6-166.fc12.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.31.5-127.fc12.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.31.6-166.fc12.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.1-20091111.tar.gz ]
+if [ ! -r ccs-patch-1.7.1-20091220.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/43375/ccs-patch-1.7.1-20091111.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/43375/ccs-patch-1.7.1-20091220.tar.gz || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
 cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- ccs-kernel.spec	2009-11-08 10:46:36.000000000 +0900
-+++ ccs-kernel.spec	2009-11-10 09:27:37.114308507 +0900
+--- ccs-kernel.spec	2009-12-09 23:39:16.000000000 +0900
++++ ccs-kernel.spec	2009-12-11 05:55:46.768877116 +0900
 @@ -15,7 +15,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.7.1
++%define buildid _tomoyo_1.7.1p1
  
  # fedora_build defines which build revision of this kernel version we're
  # building. Rather than incrementing forever, as with the prior versioning
@@ -66,7 +66,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -914,7 +919,7 @@
+@@ -917,7 +922,7 @@
  Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
@@ -75,18 +75,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1516,6 +1521,10 @@
+@@ -1526,6 +1531,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.1-20091111.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.7.1-20091220.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.31-fedora-12.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1542,6 +1551,9 @@
+@@ -1552,6 +1561,9 @@
  for i in *.config
  do
    mv $i .config
