@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.7.1   2009/11/11
+ * Version: 1.7.1+   2009/12/20
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -658,16 +658,17 @@ static int ccs_find_next_domain(struct ccs_execve_entry *ee)
 	}
 	domain = ccs_find_or_assign_new_domain(ee->tmp, r->profile);
 	if (domain)
-		ccs_audit_domain_creation_log(r->domain);
+		ccs_audit_domain_creation_log(domain);
  done:
 	if (!domain) {
-		printk(KERN_WARNING "ERROR: Domain '%s' not defined.\n",
-		       ee->tmp);
-		if (r->mode == CCS_CONFIG_ENFORCING)
-			retval = -EPERM;
-		else {
-			retval = 0;
+		retval = (r->mode == CCS_CONFIG_ENFORCING) ? -EPERM : 0;
+		if (!r->domain->domain_transition_failed) {
 			r->domain->domain_transition_failed = true;
+			ccs_write_audit_log(false, r,
+					    CCS_KEYWORD_TRANSITION_FAILED
+					    "\n");
+			printk(KERN_WARNING "ERROR: Domain '%s' not defined.\n",
+			       ee->tmp);
 		}
 	} else {
 		retval = 0;
@@ -757,6 +758,7 @@ static int ccs_environ(struct ccs_execve_entry *ee)
 	if (r->mode != 3)
 		error = 0;
 	kfree(env_page.data);
+	kfree(arg_ptr);
 	return error;
 }
 
@@ -1180,13 +1182,6 @@ int ccs_start_execve(struct linux_binprm *bprm, struct ccs_execve_entry **eep)
 	ee->previous_domain = task->ccs_domain_info;
 	/* Clear manager flag. */
 	task->ccs_flags &= ~CCS_TASK_IS_POLICY_MANAGER;
-	/* Tell GC that I started execve(). */
-	task->ccs_flags |= CCS_TASK_IS_IN_EXECVE;
-	/*
-	 * Make task->ccs_flags visible to GC before changing
-	 * task->ccs_domain_info .
-	 */
-	smp_mb();
 	*eep = ee;
 	ccs_init_request_info(&ee->r, NULL, CCS_MAC_FILE_EXECUTE);
 	ee->r.ee = ee;
@@ -1211,6 +1206,16 @@ int ccs_start_execve(struct linux_binprm *bprm, struct ccs_execve_entry **eep)
  ok:
 	if (retval < 0)
 		goto out;
+	/*
+	 * Tell GC that I started execve().
+	 * Also, tell open_exec() to check read permission.
+	 */
+	task->ccs_flags |= CCS_TASK_IS_IN_EXECVE;
+	/*
+	 * Make task->ccs_flags visible to GC before changing
+	 * task->ccs_domain_info .
+	 */
+	smp_mb();
 	/*
 	 * Proceed to the next domain in order to allow reaching via PID.
 	 * It will be reverted if execve() failed. Reverting is not good.
